@@ -1,10 +1,16 @@
 # -*- coding: utf-8 -*-
+from .errors import ArgumentError, CoordinateRangeError           # noqa:F401
+from .errors import InvalidEnumError, MissingExifDataError        # noqa:F401
+from .errors import ModelDataError                                # noqa:F401
 from .face_detection import FaceDetection, FaceDetectionModel     # noqa:F401
 from .face_detection import FaceIndex                             # noqa:F401
 from .face_landmark import FaceLandmark, face_detection_to_roi    # noqa:F401
+from .face_landmark import face_landmarks_to_render_data          # noqa:F401
 from .iris_landmark import IrisIndex, IrisLandmark, IrisResults   # noqa:F401
 from .iris_landmark import eye_landmarks_to_render_data           # noqa:F401
 from .iris_landmark import iris_depth_in_mm_from_landmarks        # noqa:F401
 from .iris_landmark import iris_landmarks_to_render_data          # noqa:F401
 from .iris_landmark import iris_roi_from_face_landmarks           # noqa:F401
-__version__ = '0.2.0'
+
+
+__version__ = '0.4.0'
